# Identity

::: torchlinops.linops.Identity
    options:
        inherited_members: false
        members:
            - __init__
            - __pow__

::: torchlinops.linops.ShapeSpec
    options:
        inherited_members: false
        members:
            - __init__
